| Client | R Documentation |
Class representing a Connect API client
Class representing a Connect API client
This class allows a user to interact with a Connect server via the Connect API. Authentication is done by providing an API key.
new()Client$new(server, api_key)
print()Client$print(...)
GET()Client$GET(path, ..., writer = httr::write_memory(), parser = "text")
content()Client$content()
server_settings()Client$server_settings()
clone()The objects of this class are cloneable with this method.
Client$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.